@@ -1,31 +1,31 @@
 #' @title
-#' Estimate the Individual Treatment Effect (ITE) using X-Learner.
+#' Estimate the Individual Treatment Effect (ITE) using X-Learner
 #'
 #' @description
 #' Estimates the Individual Treatment Effect using X-Learner given a response
 #' vector, a treatment vector, a features matrix and an estimation model for
-#' the outcome regressions.
+#' the outcome.
 #'
 #' @param y An observed response vector.
 #' @param z A treatment vector.
 #' @param X A features matrix.
-#' @param oreg_method A estimation model for the outcome regressions.
+#' @param learner_y A estimation model for the outcome.
 #'
 #' @return
 #' A list of ITE estimates.
 #'
 #' @keywords internal
 #'
-estimate_ite_xlearner <- function(y, z, X, oreg_method = "SL.xgboost") {
+estimate_ite_xlearner <- function(y, z, X, learner_y = "SL.xgboost") {
 
-  logger::log_trace("oreg_method: '{oreg_method}' was selected.")
+  logger::log_trace("learner_y: '{learner_y}' was selected.")
 
   X <- as.data.frame(X)
 
   y_0_model <- SuperLearner::SuperLearner(Y = y[z == 0],
                                           X = X[z == 0, ],
                                           family = gaussian(),
-                                          SL.library = oreg_method,
+                                          SL.library = learner_y,
                                           cvControl = list(V = 0))
 
   if (sum(y_0_model$coef) == 0) y_0_model$coef[1] <- 1
@@ -33,7 +33,7 @@ estimate_ite_xlearner <- function(y, z, X, oreg_method = "SL.xgboost") {
   y_1_model <- SuperLearner::SuperLearner(Y = y[z == 1],
                                           X = X[z == 1, ],
                                           family = gaussian(),
-                                          SL.library = oreg_method,
+                                          SL.library = learner_y,
                                           cvControl = list(V = 0))
 
   if (sum(y_1_model$coef) == 0) y_1_model$coef[1] <- 1
