@@ -1,5 +1,6 @@
 test_that("discover_rules works as expected!", {
   # Generate sample data
+  skip_on_cran()
   set.seed(2021)
   dataset_cont <- generate_cre_dataset(n = 400, rho = 0, n_rules = 2, p = 10,
                                        effect_size = 2, binary_outcome = FALSE)
@@ -9,44 +10,36 @@ test_that("discover_rules works as expected!", {
   X_names <- names(as.data.frame(X))
 
   method_params <- list(ratio_dis = 0.5,
-                        ite_method_dis = "bart",
-                        ps_method_dis = "SL.xgboost",
-                        oreg_method_dis = "SL.xgboost",
-                        ite_method_inf = "bart",
-                        ps_method_inf = "SL.xgboost",
-                        oreg_method_inf = "SL.xgboost")
+                        ite_method = "bart",
+                        learner_ps = "SL.xgboost",
+                        learner_y = "SL.xgboost")
 
   hyper_params <- list(intervention_vars = NULL,
                        offset = NULL,
-                       ntrees_rf = 100,
-                       ntrees_gbm = 50,
+                       ntrees = 30,
                        node_size = 20,
-                       max_nodes = 5,
+                       max_rules = 5,
                        max_depth = 3,
                        t_decay = 0.025,
                        t_ext = 0.025,
-                       t_corr = 1,
-                       t_pvalue = 0.05,
-                       replace = FALSE,
-                       stability_selection = TRUE,
-                       cutoff = 0.8,
-                       pfer = 1,
-                       penalty_rl = 1)
+                       t_corr = 0.2,
+                       stability_selection = "vanilla",
+                       cutoff = 0.6,
+                       pfer = 10,
+                       B = 2,
+                       subsample = 0.5)
 
   # Input checks
   check_input_data(y = y, z = z, X = X)
   method_params <- check_method_params(y = y, ite = NULL,
                                        params = method_params)
-  check_hyper_params(params = hyper_params)
+  hyper_params <- check_hyper_params(params = hyper_params)
 
   # Estimate ITE
   ite <- estimate_ite(y = y, z = z, X = X,
-                ite_method = getElement(method_params, "ite_method_dis"),
-                binary_outcome = getElement(method_params, "binary_outcome"),
-                include_ps = getElement(method_params, "include_ps_dis"),
-                ps_method = getElement(method_params, "ps_method_dis"),
-                oreg_method = getElement(method_params, "oreg_method_dis"),
-                X_names = X_names,
+                ite_method = getElement(method_params, "ite_method"),
+                learner_ps = getElement(method_params, "learner_ps"),
+                learner_y = getElement(method_params, "learner_y"),
                 offset = getElement(method_params, "offset"))
 
   # Generate Causal Decision Rules
